use clap::{arg, command};

pub fn get_args() -> clap::ArgMatches {
    command!()
        .about("Web Archive")
        .arg(
            arg!(-d --dir <dir> "Web archive directory")
                .required(false)
                .default_value("./websites"),
        )
        .subcommand(
            command!()
                .name("serve")
                .about("Start web archive server")
                .arg(
                    arg!(-c --config <config> "Web archive config file")
                        .required(false)
                        .default_value("./config.toml"),
                ),
        )
        .subcommand(
            command!()
                .name("archive")
                .about("Work with web archives")
                .subcommand(
                    command!()
                    .name("download")
                    .about("Download a new URL into the archive")
                    .arg(
                        arg!(-c --config <config> "Web archive config file")
                            .required(false)
                            .default_value("./config.toml"),
                    )
                    .arg(arg!([URL] "The URL to download").required(true))
                )
                .subcommand(
                    command!()
                        .name("list")
                        .about("List domains contained in the archive. If a domain is provided all paths of this domain will be listed.")
                        .arg(arg!([DOMAIN] "A domain to list").required(false))
                        .arg(arg!(-j --json "Ouput JSON").required(false)),
                )
                .subcommand(
                    command!()
                        .name("versions")
                        .about("List saved versions of a document")
                        .arg(arg!(-j --json "Ouput JSON").required(false))
                        .arg(arg!([DOMAIN] "A domain").required(true))
                        .arg(arg!([PATH] "A path").required(false))
                )
                .subcommand(
                    command!()
                        .name("get")
                        .about("Get a saved document")
                        .arg(arg!(--md "Ouput Markdown").required(false))
                        .arg(arg!([DOMAIN] "A domain").required(true))
                        .arg(arg!([PATH] "A path").required(false))
                        .arg(arg!([VERSION] "A version").required(false))
                ))
        .get_matches()
}
