/// Downloads a favicon for the given domain.
///
/// # Parameters
///
/// * `domain`: The domain for which to download the favicon.
///
/// # Returns
///
/// A `Vec<u8>` containing the favicon data, or `None` if an error occurred.
pub async fn download_favicon(domain: &str) -> Option<Vec<u8>> {
    let mut favicon_url = url::Url::parse(&format!("https://{}", domain)).ok()?;
    favicon_url.set_path("/favicon.ico");

    log::info!("Fetching favicon from: {}", favicon_url);

    let response = reqwest::get(favicon_url).await.ok()?;

    if !response.status().is_success() {
        return None;
    }

    let favicon_data = response.bytes().await.ok()?.to_vec();

    Some(favicon_data)
}

/// Downloads a favicon for `site` and stores it.
///
/// This will not download a favicon if it is already present.
pub async fn download_fav_for(site: &str) {
    if let Some(fav) = download_favicon(site).await {
        let fav_path = std::path::Path::new("./favicon").join(site);
        if !fav_path.exists() {
            std::fs::write(fav_path, fav).unwrap();
            log::info!("Writting favicon for {site}");
        }
    }
}

pub async fn download_favicons_for_sites(sites: &[String]) {
    for site in sites {
        download_fav_for(site).await;
    }
}
