use based::{
    request::{RequestContext, StringResponse},
    ui::components::prelude::Shell,
};
use maud::PreEscaped;

pub mod ai;
pub mod archive;
pub mod blacklist;
pub mod conf;
pub mod favicon;

use base64::prelude::*;
use sha2::{Digest, Sha256};
use std::io::Write;
use std::process::{Command, Stdio};

pub fn get_mime_type(content: &[u8]) -> std::io::Result<String> {
    let mut child = Command::new("file")
        .arg("--mime-type")
        .arg("--brief")
        .arg("-") // Read from stdin
        .stdin(Stdio::piped())
        .stdout(Stdio::piped())
        .spawn()?;

    if let Some(mut stdin) = child.stdin.take() {
        let _ = stdin.write_all(content);
    }

    let output = child.wait_with_output()?;
    Ok(String::from_utf8_lossy(&output.stdout).trim().to_string())
}

pub fn extract_data_urls(input: &str) -> Vec<(String, Vec<u8>)> {
    let data_url_regex =
        regex::Regex::new(r"data:([a-zA-Z0-9/+.-]+);base64,([a-zA-Z0-9+/=]+)").unwrap();

    let mut results = Vec::new();

    for cap in data_url_regex.captures_iter(input) {
        if let (Some(mime), Some(encoded)) = (cap.get(1), cap.get(2)) {
            if let Ok(decoded) = BASE64_STANDARD.decode(encoded.as_str()) {
                results.push((mime.as_str().to_string(), decoded));
            }
        }
    }

    results
}

pub fn from_base64(input: &str) -> Vec<u8> {
    BASE64_STANDARD.decode(input).unwrap()
}

pub fn sha256_hash(input: &[u8]) -> String {
    let mut hasher = Sha256::new();
    hasher.update(input);
    format!("{:x}", hasher.finalize())
}

pub async fn render_page(
    content: PreEscaped<String>,
    ctx: RequestContext,
    shell: &Shell,
) -> StringResponse {
    shell.render_page(content, "Website Archive", ctx).await
}
